summaryrefslogtreecommitdiff
path: root/cl/cl_mactotei.h
diff options
context:
space:
mode:
authorlaranjeiro2007-12-21 08:03:15 +0000
committerlaranjeiro2007-12-21 08:03:15 +0000
commit2bbe17dd3c3cc51f2af94b1a2f50807bb4b504ae (patch)
tree7665c20e5bd8d72c2312a7bea7cc299d921c2b07 /cl/cl_mactotei.h
parent78d720e4a1d647893f7063de717389a988a0f082 (diff)
Added traces in the CL module.
git-svn-id: svn+ssh://pessac/svn/cesar/trunk@1176 017c9cb6-072f-447c-8318-d5b54f68fe89
Diffstat (limited to 'cl/cl_mactotei.h')
-rw-r--r--cl/cl_mactotei.h27
1 files changed, 6 insertions, 21 deletions
diff --git a/cl/cl_mactotei.h b/cl/cl_mactotei.h
index f60875cf91..4f74b62bf5 100644
--- a/cl/cl_mactotei.h
+++ b/cl/cl_mactotei.h
@@ -59,41 +59,26 @@ void cl_mactotei_addr_add (cl_mactotei_blk_t *table, mac_t mac_addr,
* Sample : cl_mactotei_copy_table_excluding_tag (cl, table, 2), will copy all
* the mac to tei lines of the CL table without those where the tag value is 2.
*
* \param cl the convergence layer context
* \param table the mactotei new table to fill
* \param tag the tag to exclude from the copy
*/
-void cl_mactotei_copy_table_excluding_tag (cl_t *cl,
+void cl_mactotei_copy_table_excluding_tag (cl_t *ctx,
cl_mactotei_blk_t *table, u8 tag);
/**
* Request the CL to use the new table and remove the old one.
*
* \msc
* CP, CL, CL_MACTOTEI;
*
* CP->CL [label = "cl_mactotei_use_table (cl, table)"];
* CL->CL_MACTOTEI [label = "cl_mactotei_use_table_intern (table)"];
* CL<<CL_MACTOTEI [label = "done"];
* CL->CL [label = "cl_mactotei_switch_table (cl, table)"];
* \endmsc
*
* \param cl the CL context
* \param table the new table to use.
*/
-void cl_mactotei_use_table (cl_t *cl, cl_mactotei_blk_t *table);
+void cl_mactotei_use_table (cl_t *ctx, cl_mactotei_blk_t *table);
/**
* Release the complete table from the memory.
*
* \msc
* CL, CL_MACTOTEI;
*
* CL->CL_MACTOTEI [label = "cl_mactotei_release_table_intern (table)"];
* \endmsc
*
* \param cl the convergence layer context
*/
-void cl_mactotei_release_table (cl_t *cl);
+void cl_mactotei_release_table (cl_t *ctx);
#endif /*CL_MACTOTEI_H_*/
@@ -59,41 +59,26 @@ void cl_mactotei_addr_add (cl_mactotei_blk_t *table, mac_t mac_addr,
* the mac to tei lines of the CL table without those where the tag value is 2.
*
- * \param cl the convergence layer context
+ * \param ctx the convergence layer context
* \param table the mactotei new table to fill
* \param tag the tag to exclude from the copy
@@ -59,41 +59,26 @@ void cl_mactotei_addr_add (cl_mactotei_blk_t *table, mac_t mac_addr,
* Request the CL to use the new table and remove the old one.
*
- * \msc
- * CP, CL, CL_MACTOTEI;
- *
- * CP->CL [label = "cl_mactotei_use_table (cl, table)"];
- * CL->CL_MACTOTEI [label = "cl_mactotei_use_table_intern (table)"];
- * CL<<CL_MACTOTEI [label = "done"];
- * CL->CL [label = "cl_mactotei_switch_table (cl, table)"];
- * \endmsc
- *
- * \param cl the CL context
+ * \param ctx the CL context
* \param table the new table to use.
*/
@@ -59,41 +59,26 @@ void cl_mactotei_addr_add (cl_mactotei_blk_t *table, mac_t mac_addr,
* Release the complete table from the memory.
*
- * \msc
- * CL, CL_MACTOTEI;
- *
- * CL->CL_MACTOTEI [label = "cl_mactotei_release_table_intern (table)"];
- * \endmsc
- *
- * \param cl the convergence layer context
+ * \param ctx the convergence layer context
*/